==> phyddle-0.0.10.tar.gz: phyddle-0.0.10/scripts/config_Rev.py <==
#==============================================================================#
# Default phyddle config file                                                  #
#==============================================================================#

# external import
#import scipy as sp

# helper variables
num_char = 2
num_states = 3

args = {
    
    #-------------------------------#
    # Project organization          #
    #-------------------------------#
    'proj'           : 'Rev_example',            # directory name for pipeline project
    'step'           : 'SFTEP',                  # steps to run? all, sim, fmt, trn, est, plt
    'verbose'        : 'T',
    'sim_dir'        : '../workspace/simulate',  # directory for simulated data
    'fmt_dir'        : '../workspace/format',    # directory for tensor-formatted data
    'trn_dir'        : '../workspace/train',     # directory for trained network
    'plt_dir'        : '../workspace/plot',      # directory for plotted figures
    'est_dir'        : '../workspace/estimate',  # directory for predictions on new data
    'log_dir'        : '../workspace/log',       # directory for logging metadata
    
    #-------------------------------#
    # Multiprocessing               #
    #-------------------------------#
    'use_parallel'   : 'T',                # use multiprocessing to speed up jobs?
    'num_proc'       : -2,                  # how many CPUs to use (-2 means all but 2)
    
    #-------------------------------#
    # Simulate settings             #
    #-------------------------------#
    'sim_command'       : 'rb sim/Rev/sim_one.Rev --args',   # exact command string, argument is output file prefix
    'sim_logging'       : 'verbose',        # verbose, compressed, or clean
    'start_idx'         : 0,                # first simulation replicate index
    'end_idx'           : 1000,             # last simulation replicate index
    'sim_batch_size'    : 100,              # number of simulations per batch

    #-------------------------------#
    # Format settings               #
    #-------------------------------#
    'num_char'          : 2,                # number of evolutionary characters
    'num_states'        : 3,                # number of states per discrete character
    'min_num_taxa'      : 10,
    'max_num_taxa'      : 500,
    'tree_width_cats'   : 200,              # tree width categories for phylo-state tensors
    'tree_encode'       : 'extant',         # use model with serial or extant tree
    'brlen_encode'      : 'height_brlen',   # how to encode phylo brlen? height_only or height_brlen
    'char_encode'       : 'one_hot',        # how to encode discrete states? one_hot or integer 
    'param_est'        : [                  # model parameters to predict (labels)
        'birth', 'death', 'state_rate'
    ],
    'param_data'        : [],               # model parameters that are known (aux. data)
    'tensor_format'     : 'hdf5',           # save as compressed HDF5 or raw csv
    'char_format'       : 'nexus',          # expect character data is in nexus or csv format
    'save_phyenc_csv'   : 'F',              # save intermediate phylo-state vectors to file

    #-------------------------------#
    # Train settings                #
    #-------------------------------#
    'trn_objective'     : 'param_est',      # what is the learning task? param_est or model_test
    'tree_width'        : 500,              # tree width category used to train network
    'num_epochs'        : 20,               # number of training intervals (epochs)
    'prop_test'         : 0.05,             # proportion of sims in test dataset
    'prop_val'          : 0.05,             # proportion of sims in validation dataset
    'prop_cal'          : 0.20,             # proportion of sims in CPI calibration dataset 
    'cpi_coverage'      : 0.95,             # coverage level for CPIs
    'cpi_asymmetric'    : 'T',              # two-sided (True) or one-sided (False) CPI adjustments
    'trn_batch_size'    : 128,              # number of samples in each training batch
    'loss'              : 'mse',            # loss function for learning
    'optimizer'         : 'adam',           # optimizer for network weight/bias parameters
    'metrics'           : ['mae', 'acc'],   # recorded training metrics

    #-------------------------------#
    # Estimate settings             #
    #-------------------------------#
    'est_prefix'     : 'new.1',             # prefix for new dataset to predict

    #-------------------------------#
    # Plot settings                 #
    #-------------------------------#
    'plot_train_color'      : 'blue',       # plot color for training data
    'plot_test_color'       : 'purple',     # plot color for test data
    'plot_val_color'        : 'red',        # plot color for validation data
    'plot_aux_color'        : 'green',      # plot color for input auxiliary data
    'plot_label_color'      : 'orange',     # plot color for labels (params)
    'plot_est_color'        : 'black',      # plot color for predictions

}

==> phyddle-0.1.0.tar.gz: phyddle-0.1.0/scripts/config_Rev.py <==
#==============================================================================#
# Default phyddle config file                                                  #
#==============================================================================#

args = {
    
    #-------------------------------#
    # Project organization          #
    #-------------------------------#
    'proj'           : 'Rev_GeoSSE',             # directory name for pipeline project
    'step'           : 'SFTEP',                  # steps to run? all, sim, fmt, trn, est, plt
    'verbose'        : 'T',
    'sim_dir'        : '../workspace/simulate',  # directory for simulated data
    'fmt_dir'        : '../workspace/format',    # directory for tensor-formatted data
    'trn_dir'        : '../workspace/train',     # directory for trained network
    'plt_dir'        : '../workspace/plot',      # directory for plotted figures
    'est_dir'        : '../workspace/estimate',  # directory for predictions on new data
    'log_dir'        : '../workspace/log',       # directory for logging metadata
    
    #-------------------------------#
    # Multiprocessing               #
    #-------------------------------#
    'use_parallel'   : 'T',                 # use multiprocessing to speed up jobs?
    'num_proc'       : -2,                  # how many CPUs to use (-2 means all but 2)
    
    #-------------------------------#
    # Simulate settings             #
    #-------------------------------#
    'sim_command'       : 'rb sim/Rev/sim_geosse.Rev --args',   # exact command string, argument is output file prefix
    'sim_logging'       : 'verbose',        # verbose, compressed, or clean
    'start_idx'         : 0,                # first simulation replicate index
    'end_idx'           : 100,              # last simulation replicate index
    'sim_batch_size'    : 100,               # number of simulations per batch

    #-------------------------------#
    # Format settings               #
    #-------------------------------#
    'encode_all_sim'    : 'T',              # encode all simulated datasets
    'num_char'          : 1,                # number of evolutionary characters
    'num_states'        : 7,                # number of states per discrete character
    'min_num_taxa'      : 10,
    'max_num_taxa'      : 500,
    'tree_width'        : 500,              # tree width category used to train network
    'tree_encode'       : 'extant',         # use model with serial or extant tree
    'brlen_encode'      : 'height_brlen',   # how to encode phylo brlen? height_only or height_brlen
    'char_encode'       : 'one_hot',        # how to encode discrete states? one_hot or integer 
    'param_est'        : [                  # model parameters to predict (labels)
        'rho_w','rho_d','rho_e','rho_b'
    ],
    'param_data'        : [                 # model parameters that are known (aux. data)
        'sample_frac'
    ],               
    'tensor_format'     : 'hdf5',           # save as compressed HDF5 or raw csv
    'char_format'       : 'nexus',          # expect character data is in nexus or csv format
    'save_phyenc_csv'   : 'F',              # save intermediate phylo-state vectors to file

    #-------------------------------#
    # Train settings                #
    #-------------------------------#
    'trn_objective'     : 'param_est',      # what is the learning task? param_est or model_test
    'num_epochs'        : 20,               # number of training intervals (epochs)
    'prop_test'         : 0.05,             # proportion of sims in test dataset
    'prop_val'          : 0.05,             # proportion of sims in validation dataset
    'prop_cal'          : 0.20,             # proportion of sims in CPI calibration dataset 
    'combine_test_val'  : 'F',
    'cpi_coverage'      : 0.95,             # coverage level for CPIs
    'cpi_asymmetric'    : 'T',              # two-sided (True) or one-sided (False) CPI adjustments
    'trn_batch_size'    : 1024,             # number of samples in each training batch
    'loss'              : 'mse',            # loss function for learning
    'optimizer'         : 'adam',           # optimizer for network weight/bias parameters
    'metrics'           : ['mae', 'acc'],   # recorded training metrics
    'log_offset'        : 1.0,

    #-------------------------------#
    # Estimate settings             #
    #-------------------------------#
    'est_prefix'     : 'new.0',             # prefix for new dataset to predict

    #-------------------------------#
    # Plot settings                 #
    #-------------------------------#
    'plot_train_color'      : 'blue',       # plot color for training data
    'plot_test_color'       : 'purple',     # plot color for test data
    'plot_val_color'        : 'red',        # plot color for validation data
    'plot_aux_color'        : 'green',      # plot color for input auxiliary data
    'plot_label_color'      : 'orange',     # plot color for labels (params)
    'plot_est_color'        : 'black',      # plot color for predictions

}
